@@ -59,7 +59,7 @@ public:
                       
     void endElement(const gchar* pName, ODi_ListenerStateAction& rAction);
     
-    void charData (const gchar* pBuffer, int length) {}
+    void charData (const gchar* /*pBuffer*/, int /*length*/) {}
     
     
     const UT_UTF8String& getDisplayName() const {return m_displayName;}
@@ -181,7 +181,7 @@ public:
      */
     const UT_UTF8String* getWrap(bool local) const;
     
-    const UT_UTF8String* getBackgroundColor() const {return &m_backgroundColor;}
+    const UT_UTF8String* getBackgroundColor() const;
     
     const UT_UTF8String* getColumnWidth() const {return &m_columnWidth;}
     
