@@ -23,10 +23,15 @@
 #ifndef _OXMLI_LISTENERSTATE_THEME_H_
 #define _OXMLI_LISTENERSTATE_THEME_H_
 
-#include "OXMLi_ListenerState.h"
+// Internal includes
+#include <OXMLi_ListenerState.h>
 #include <OXMLi_Types.h>
 #include <OXML_Types.h>
+#include "OXML_Theme.h"
 
+/* \class OXMLi_ListenerState_Theme
+ * \brief This ListenerState parses the Theme part.
+*/
 class OXMLi_ListenerState_Theme : public OXMLi_ListenerState
 {
 public:
